@@ -1,10 +1,15 @@
 import sys
-from typing import Iterator, Optional, List
+from typing import Iterator, Optional, List, Tuple, Any, Union
 
 import ast as ast_module
 from robocorp_ls_core.lsp import Error
 from robocorp_ls_core.robotframework_log import get_logger
-from robotframework_ls.impl.protocols import TokenInfo, NodeInfo, KeywordUsageInfo
+from robotframework_ls.impl.protocols import (
+    TokenInfo,
+    NodeInfo,
+    KeywordUsageInfo,
+    ILibraryImportNode,
+)
 
 
 log = get_logger(__name__)
@@ -83,10 +88,9 @@ class _PrinterVisitor(ast_module.NodeVisitor):
                     )
                 )
 
-            ret = ast_module.NodeVisitor.generic_visit(self, node)
+            ast_module.NodeVisitor.generic_visit(self, node)
         finally:
             self._level -= 1
-        return ret
 
 
 MAX_ERRORS = 100
@@ -127,7 +131,7 @@ def create_error_from_node(node, msg, tokens=None) -> Error:
         tokens = node.tokens
 
     if not tokens:
-        log.log("No tokens found when visiting %s." % (node.__class__,))
+        log.info("No tokens found when visiting: %s.", node.__class__)
         start = (0, 0)
         end = (0, 0)
     else:
@@ -198,6 +202,8 @@ def find_token(ast, line, col) -> Optional[TokenInfo]:
             tokens = node.tokens
         except AttributeError:
             continue
+
+        last_token = None
         for token in tokens:
             lineno = token.lineno - 1
             if lineno != line:
@@ -209,10 +215,25 @@ def find_token(ast, line, col) -> Optional[TokenInfo]:
                 # not the separator.
                 if token.col_offset < col < token.end_col_offset:
                     return TokenInfo(tuple(stack), node, token)
+
+            elif token.type == token.EOL:
+                # A trailing whitespace after a keyword should be part of
+                # the keyword, not EOL.
+                if token.col_offset <= col <= token.end_col_offset:
+                    diff = col - token.col_offset
+                    if last_token is not None and not token.value.strip():
+                        eol_contents = token.value[:diff]
+                        if len(eol_contents) <= 1:
+                            token = _append_eol_to_prev_token(last_token, eol_contents)
+
+                    return TokenInfo(tuple(stack), node, token)
+
             else:
                 if token.col_offset <= col <= token.end_col_offset:
                     return TokenInfo(tuple(stack), node, token)
 
+            last_token = token
+
     return None
 
 
@@ -291,10 +312,9 @@ def _tokenize_variables_even_when_invalid(token, col):
             ]
 
 
-def _iter_nodes_filtered(ast, accept_class, recursive=True):
-    """
-    :rtype: generator(tuple(list,ast_module.AST))
-    """
+def _iter_nodes_filtered(
+    ast, accept_class: Union[Tuple[str, ...], str], recursive=True
+) -> Iterator[Tuple[list, Any]]:
     if not isinstance(accept_class, (list, tuple, set)):
         accept_class = (accept_class,)
     for stack, node in _iter_nodes(ast, recursive=recursive):
@@ -302,7 +322,34 @@ def _iter_nodes_filtered(ast, accept_class, recursive=True):
             yield stack, node
 
 
-def iter_library_imports(ast) -> Iterator[NodeInfo]:
+LIBRARY_IMPORT_CLASSES = ("LibraryImport",)
+RESOURCE_IMPORT_CLASSES = ("ResourceImport",)
+SETTING_SECTION_CLASSES = ("SettingSection",)
+
+
+def iter_nodes(
+    ast, accept_class: Union[Tuple[str, ...], str], recursive=True
+) -> Iterator[NodeInfo]:
+    if not isinstance(accept_class, (list, tuple, set)):
+        accept_class = (accept_class,)
+    for stack, node in _iter_nodes(ast, recursive=recursive):
+        if node.__class__.__name__ in accept_class:
+            yield NodeInfo(tuple(stack), node)
+
+
+def is_library_node_info(node_info: NodeInfo) -> bool:
+    return node_info.node.__class__.__name__ in LIBRARY_IMPORT_CLASSES
+
+
+def is_resource_node_info(node_info: NodeInfo) -> bool:
+    return node_info.node.__class__.__name__ in RESOURCE_IMPORT_CLASSES
+
+
+def is_setting_section_node_info(node_info: NodeInfo) -> bool:
+    return node_info.node.__class__.__name__ in SETTING_SECTION_CLASSES
+
+
+def iter_library_imports(ast) -> Iterator[NodeInfo[ILibraryImportNode]]:
     for stack, node in _iter_nodes_filtered(ast, accept_class="LibraryImport"):
         yield NodeInfo(tuple(stack), node)
 
@@ -505,3 +552,17 @@ def _strip_token_bdd_prefix(token):
                 error=token.error,
             )
     return token
+
+
+def _append_eol_to_prev_token(last_token, eol_token_contents):
+    from robot.api import Token
+
+    new_value = last_token.value + eol_token_contents
+
+    return Token(
+        type=last_token.type,
+        value=new_value,
+        lineno=last_token.lineno,
+        col_offset=last_token.col_offset,
+        error=last_token.error,
+    )
