@@ -8,6 +8,9 @@ OPTION_ROBOT_LANGUAGE_SERVER_ARGS = "robot.language-server.args"
 
 OPTION_ROBOT_VARIABLES = "robot.variables"
 OPTION_ROBOT_PYTHONPATH = "robot.pythonpath"
+OPTION_ROBOT_WORKSPACE_SYMBOLS_ONLY_FOR_OPEN_DOCS = (
+    "robot.workspaceSymbolsOnlyForOpenDocs"
+)
 
 OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM = "robot.completions.section_headers.form"
 OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_PLURAL = "plural"
@@ -27,5 +30,6 @@ ALL_ROBOT_OPTIONS = frozenset(
         OPTION_ROBOT_VARIABLES,
         OPTION_ROBOT_PYTHONPATH,
         OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM,
+        OPTION_ROBOT_WORKSPACE_SYMBOLS_ONLY_FOR_OPEN_DOCS,
     )
 )
